@@ -8,6 +8,7 @@ import time
 import numpy as np
 
 from . import gradients as grad
+from .backend import backend_name
 from .utils import list_to_str, save_animation
 
 
@@ -115,8 +116,9 @@ class ModelCheckpoint(Callback):
     Args:
         filepath (string): Path to save the model file.
         verbose: Verbosity mode, 0 or 1.
-        save_better_only: If True, only save a better model according to the quantity monitored.
-            Model is only checked at validation step according to ``display_every`` in ``Model.train``.
+        save_better_only: If True, only save a better model according to the quantity
+            monitored. Model is only checked at validation step according to
+            ``display_every`` in ``Model.train``.
         period: Interval (number of epochs) between checkpoints.
     """
 
@@ -255,7 +257,7 @@ class VariableValue(Callback):
 
     def __init__(self, var_list, period=1, filename=None, precision=2):
         super(VariableValue, self).__init__()
-        self.var_list = var_list
+        self.var_list = var_list if isinstance(var_list, list) else [var_list]
         self.period = period
         self.precision = precision
 
@@ -264,14 +266,20 @@ class VariableValue(Callback):
         self.epochs_since_last = 0
 
     def on_train_begin(self):
-        self.value = self.model.sess.run(self.var_list)
+        if backend_name == "tensorflow.compat.v1":
+            self.value = self.model.sess.run(self.var_list)
+        elif backend_name == "tensorflow":
+            self.value = [var.numpy() for var in self.var_list]
         print(self.model.train_state.epoch, self.value, file=self.file)
 
     def on_epoch_end(self):
         self.epochs_since_last += 1
         if self.epochs_since_last >= self.period:
             self.epochs_since_last = 0
-            self.value = self.model.sess.run(self.var_list)
+            if backend_name == "tensorflow.compat.v1":
+                self.value = self.model.sess.run(self.var_list)
+            elif backend_name == "tensorflow":
+                self.value = [var.numpy() for var in self.var_list]
             print(
                 self.model.train_state.epoch,
                 list_to_str(self.value, precision=self.precision),
@@ -357,6 +365,12 @@ class MovieDumper(Callback):
         self.spectrum = []
         self.epochs_since_last_save = 0
 
+        # TODO: support backend tensorflow
+        if backend_name != "tensorflow.compat.v1":
+            raise RuntimeError(
+                "MovieDumper only supports backend tensorflow.compat.v1."
+            )
+
     def init(self):
         self.tf_op = self.model.net.outputs[:, self.component]
         self.feed_dict = self.model.net.feed_dict(False, False, 2, self.x)
@@ -412,7 +426,7 @@ class MovieDumper(Callback):
 
 
 class PDEResidualResampler(Callback):
-    """Resample the training data every given period."""
+    """Resample the training points for PDE losses every given period."""
 
     def __init__(self, period=100):
         super(PDEResidualResampler, self).__init__()
